@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -9,10 +9,10 @@
 
 #include <KContacts/VCardConverter>
 
-#include <Akonadi/Contact/ContactGroupViewer>
-#include <Akonadi/Contact/ContactViewer>
-#include <Akonadi/Contact/GrantleeContactFormatter>
-#include <Akonadi/Contact/GrantleeContactGroupFormatter>
+#include <Akonadi/ContactGroupViewer>
+#include <Akonadi/ContactViewer>
+#include <Akonadi/GrantleeContactFormatter>
+#include <Akonadi/GrantleeContactGroupFormatter>
 #include <Akonadi/Item>
 #include <KLocalizedString>
 
@@ -26,7 +26,7 @@
 ContactPreviewWidget::ContactPreviewWidget(const QString &projectDirectory, QWidget *parent)
     : QWidget(parent)
 {
-    QHBoxLayout *lay = new QHBoxLayout(this);
+    auto lay = new QHBoxLayout(this);
     lay->setContentsMargins(0, 0, 0, 0);
     mTabWidget = new QTabWidget;
 
